SystemOrganization addCategory: #'WorldSwitch-Preferences'!

Object subclass: #WSSettings
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WorldSwitch-Preferences'!

WSSettings class
	instanceVariableNames: 'deployment shouldSaveBeforeQuit windowTitle'!

WSSettings class
	instanceVariableNames: 'deployment shouldSaveBeforeQuit windowTitle'!

!WSSettings class methodsFor: 'settings' stamp: 'EstebanLorenzano 2/2/2012 09:30'!
deploymentSettingsOn: aBuilder
	<systemsettings>

	(aBuilder group: #deployment) 
		label: 'Deployment' translated;
		description: 'Settings for deployment mode' translated;
		with: [
			(aBuilder setting: #deploymentMode)
				label: 'Deployment Mode' translated;
				getSelector: #isDeployment;
				setSelector: #setDeployment:;
				description: 'Prepares image as deployment mode (removes all deployment tools)' translated;
				default: false.

			(aBuilder setting: #shouldSaveBeforeQuit)
				label: 'Save before quit' translated;
				getSelector: #shouldSaveBeforeQuit;
				setSelector: #setShouldSaveBeforeQuit:;
				description: 'Saves image when quit on deployment mode' translated;
				default: true.
				
			(aBuilder setting: #windowTitle)
				label: 'Window Title' translated;
				ghostHelp: 'Application title';
				getSelector: #windowTitle;
				setSelector: #setWindowTitle:;
				description: 'Title of host window on deployment' translated;
				default: ''  ].! !

!WSSettings class methodsFor: 'testing' stamp: 'EstebanLorenzano 2/2/2012 08:38'!
isDeployment
	^deployment ifNil: [ false ]! !

!WSSettings class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2012 09:34'!
setDeployment: aBoolean
	aBoolean ifTrue: [ 
		(self confirm: 'WARNING!! This will disable all development tools for your image. 
Are you sure?' translated)
			ifFalse: [ ^self ] ].
		
	deployment := aBoolean.
	aBoolean 
		ifTrue: [ self new prepareAsDeployment ]
		ifFalse: [ self new prepareAsDevelopment ]..! !

!WSSettings class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2012 09:15'!
setShouldSaveBeforeQuit: aBoolean
	shouldSaveBeforeQuit := aBoolean! !

!WSSettings class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2012 09:25'!
setWindowTitle: aString
	windowTitle := aString! !

!WSSettings class methodsFor: 'testing' stamp: 'EstebanLorenzano 2/2/2012 09:19'!
shouldSaveBeforeQuit
	^shouldSaveBeforeQuit ifNil: [ true ]! !

!WSSettings class methodsFor: 'system startup' stamp: 'EstebanLorenzano 2/2/2012 09:27'!
startUp: resuming
	resuming 
		ifTrue: [ self new startUp ]! !

!WSSettings class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/2/2012 09:25'!
windowTitle
	^windowTitle! !

!WSSettings methodsFor: 'private' stamp: 'EstebanLorenzano 2/2/2012 08:55'!
cleanUpEnvironment
	(self confirm: 'Clean environment for production?' translated)
		ifFalse: [ ^self ].
		
	[ Smalltalk cleanUp: true ] valueSupplyingAnswer: true.
	ScriptLoader new cleanUpForDesktopProduction.! !

!WSSettings methodsFor: 'private' stamp: 'EstebanLorenzano 2/2/2012 10:27'!
environmentSettingsTo: aBoolean
	SmalltalkImage 
		checkChangesFileAvailability: aBoolean;
		checkSourcesFileAvailability: aBoolean.
	"No user-interrupt-into-debugger"
	UserInterruptHandler cmdDotEnabled: aBoolean.
	"turn off shift-click editing"
	StringMorph editableStringMorph: aBoolean.
	"No halos, etc." 
	Morph cmdGesturesEnabled: aBoolean. 
	"No user commands invokable via cmd-key combos in text editor"
	Editor cmdKeysInText: aBoolean.
! !

!WSSettings methodsFor: 'as yet unclassified' stamp: 'EstebanLorenzano 2/2/2012 10:20'!
prepareAsDeployment 
	self cleanUpEnvironment.
	self environmentSettingsTo: false.		
	WSDebugger registerToolsOn: Smalltalk tools.	
	Smalltalk addToStartUpList: self class.
	WorldState saveAs.! !

!WSSettings methodsFor: 'as yet unclassified' stamp: 'EstebanLorenzano 2/2/2012 10:20'!
prepareAsDevelopment 
	Smalltalk removeFromStartUpList: self class.
	self environmentSettingsTo: true.
	Debugger registerToolsOn: Smalltalk tools.	
	Smalltalk removeFromStartUpList: self class.
	WorldState saveAs.! !

!WSSettings methodsFor: 'private' stamp: 'usmanbhatti 3/6/2012 16:48'!
prepareMorph: aMorph

    World color: Color lightGray lighter lighter.
    World removeAllMorphs.
    World layoutPolicy: ProportionalLayout new. 
    World 
        addMorph: aMorph 
        fullFrame: (LayoutFrame fractions: (0@0 corner: 1@1)).
    aMorph bounds: World bounds.
    aMorph sticky: true! !

!WSSettings methodsFor: 'as yet unclassified' stamp: 'usmanbhatti 3/7/2012 12:43'!
startUp 
	self class windowTitle isEmptyOrNil
		ifFalse: [ 
			DisplayScreen hostWindowTitle: self class windowTitle.
			self flag: #fixme. "Incredible ugly hack, because host window plugin is not working on linux"
			OSPlatform isUnix  
				ifTrue: [ Smalltalk imageName: self class windowTitle ] ]! !

!WorldState class methodsFor: '*worldswitch-preferences-overrides' stamp: 'EstebanLorenzano 1/5/2012 14:17'!
quitSession
	Smalltalk
		snapshot: (self shouldSaveBeforeQuit ifNil: [ ^self ])
		andQuit: true! !

!WorldState class methodsFor: '*worldswitch-preferences-overrides' stamp: 'EstebanLorenzano 2/2/2012 09:31'!
shouldSaveBeforeQuit 
	^WSSettings isDeployment 
		ifTrue: [ WSSettings shouldSaveBeforeQuit ] 
		ifFalse: [ self confirm: 'Save changes before quitting?' translated orCancel: [ ^nil] ]! !

Debugger subclass: #WSDebugger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'WorldSwitch-Preferences'!

!WSDebugger class methodsFor: 'private' stamp: 'EstebanLorenzano 1/6/2012 11:18'!
errorFileName 
	^'PharoDebug.log' "'error-{1}' format: {Date today yyyymmdd}"! !

!WSDebugger class methodsFor: 'private' stamp: 'EstebanLorenzano 1/6/2012 20:42'!
errorText 
	^'An Error happened!! 
Please send "{1}" file to email: muni+error@smallworks.com.ar'! !

!WSDebugger class methodsFor: 'as yet unclassified' stamp: 'EstebanLorenzano 1/6/2012 20:11'!
isActive 
	"Answers if this is the active debugger.
	 As ToolRegistry does not have any way to test for a registered tool, I need to hack it :("
	self flag: #todo. "Fix this ugly hack"
	^((Smalltalk tools instVarNamed: 'tools') at:#debugger) = self! !

!WSDebugger class methodsFor: 'initialization' stamp: 'EstebanLorenzano 1/20/2012 16:50'!
openContext: aContext label: aString contents: contentsStringOrNil
	Smalltalk logError: aString inContext: aContext.
	(self context: aContext)
		openNotifierContents: contentsStringOrNil
		label: aString.
	self showErrorMessage: aString contents: contentsStringOrNil. 
	Processor activeProcess terminate.! !

!WSDebugger class methodsFor: 'opening' stamp: 'EstebanLorenzano 11/23/2011 16:12'!
openFileNamed: aString
	| newContext |

  	newContext := FileDirectory default 
		readOnlyFileNamed: aString
		do: [ :stream | 
			stream binary.
			FLMaterializer materializeFromByteArray: stream contents ].

    	Debugger 
		openContext: newContext 
		label:  'Debug Remote Error' 
		contents: nil
! !

!WSDebugger class methodsFor: 'opening' stamp: 'EstebanLorenzano 11/23/2011 09:34'!
openOn: process context: context label: title contents: contentsStringOrNil fullView: bool 
	self 
		openContext: context 
		label: title 
		contents: contentsStringOrNil! !

!WSDebugger class methodsFor: 'tools registry' stamp: 'EstebanLorenzano 11/23/2011 09:28'!
registerToolsOn: registry
	"self registerToolsOn: Smalltalk tools " 
	registry register: self as: #debugger
! !

!WSDebugger class methodsFor: 'private' stamp: 'EstebanLorenzano 12/10/2011 14:46'!
saveError: aContext
	| file copiedContext |

	copiedContext := aContext veryDeepCopy.
	
	file := (FSFilesystem disk workingDirectory / self errorFileName) withExtension: 'dump'.
	file exists ifTrue: [ file delete ].
	FileStream 
		forceNewFileNamed: file fullName 
		do: [ :stream | 
			stream binary.
			FLSerializer newDefault  
				"showProgress;"
				serialize: copiedContext
				on: stream ].! !

!WSDebugger class methodsFor: 'private' stamp: 'EstebanLorenzano 12/10/2011 14:47'!
showErrorMessage: labelString contents: contentsStringOrNil
	| text dialog width |

	text := self errorText format: {self errorFileName. labelString. contentsStringOrNil}.
	width := 0.
	text linesDo: [ :l | width := width max: (UITheme current textFont widthOfStringOrText: l) ].
	dialog := ErrorDialogWindow new 
		textFont: StandardFonts defaultFont;
		title: 'Error';
		text: text.
	dialog width: (width + 120 min: Display width - 50).	
	World openModal: dialog.
! !

!WSDebugger methodsFor: 'as yet unclassified' stamp: 'EstebanLorenzano 1/20/2012 16:49'!
openNotifierContents: msgString label: label	
	"| c |
	c := contextStackTop veryDeepCopy.
	self class saveError: c."
	errorWasInUIProcess := UIManager default spawnNewProcessIfThisIsUI: interruptedProcess.
	! !

!PasteUpMorph methodsFor: '*worldswitch-preferences-overrides' stamp: 'EstebanLorenzano 2/2/2012 09:31'!
invokeWorldMenu: evt
	"Put up the world menu, triggered by the passed-in event."
	| menu |
	
	WSSettings isDeployment 
		ifTrue: [ ^nil ].
	
	self bringTopmostsToFront.
	"put up screen menu"
	(menu := self worldMenu) popUpEvent: evt in: self.
	^ menu! !

!Morph methodsFor: '*worldswitch-preferences-overrides' stamp: 'EstebanLorenzano 2/2/2012 09:31'!
invokeMetaMenu: evt
	| menu |

	WSSettings isDeployment ifTrue: [ ^self ].

	menu := self buildMetaMenu: evt.
	menu addTitle: self externalName.
	self world ifNotNil: [
		menu popUpEvent: evt in: self world
	]! !

!ScriptLoader methodsFor: '*worldswitch-preferences-extensions' stamp: 'NouryBouraqadi 4/20/2012 17:04'!
cleanUpForDesktopProduction
	"This is same as cleanUpForProduction, but it does not remove DejaVu fonts"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].
	(MCPackage named: 'HelpSystem-Core') unload.
	(MCPackage named: 'Deprecated12') unload.
	(MCPackage named: 'Deprecated13') unload.
	(MCPackage named: 'ToolBuilder-Morphic') unload.
	(MCPackage named: 'ToolBuilder-Kernel') unload.
	
	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehash].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	(MCPackage named: 'Graphics-Resources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	RecentMessageList cleanUp.
	Smalltalk garbageCollect
	! !

!TextMorphForFieldView methodsFor: '*worldswitch-preferences-overrides' stamp: 'EstebanLorenzano 2/2/2012 09:31'!
keyboardFocusChange: aBoolean 
	"If we are losing focus and have acceptOnFocusChange then accept."
	
	WSSettings isDeployment 
		ifFalse: [
			aBoolean
				ifTrue: [self editView selectAll]
				ifFalse: [self editView selectFrom: 1 to: 0] ].
	super keyboardFocusChange: aBoolean! !
